.. AUTO-GENERATED FILE -- DO NOT EDIT!

torch.imdb
==========

Module: :mod:`torch.imdb`
-------------------------
.. automodule:: ISLP.torch.imdb

.. currentmodule:: ISLP.torch.imdb

Functions
---------


.. autofunction:: ISLP.torch.imdb.load_lookup


.. autofunction:: ISLP.torch.imdb.load_sequential


.. autofunction:: ISLP.torch.imdb.load_sparse


.. autofunction:: ISLP.torch.imdb.load_tensor

